# 知识库

## 数据模型

### 1.知识库类型

| 编码(code,接口中使用的typeCode) | 类型说明           |
| ------------------------------- | ------------------ |
| geography                       | 省市信息           |
| equipment_all                   | 设备类型           |
| equipment_family                | 种族类型           |
| climate                         | 气候区             |
| develop                         | 发展水平           |
| weather                         | 天气状态           |
| wind                            | 空气风力等级       |
| direction                       | 方位信息           |
| building                        | 建筑功能类型       |
| space                           | 空间功能类型       |
| rental                          | 租赁业态           |
| dustproof                       | 防尘等级           |
| waterproof                      | 防水等级           |
| explosionproof_equipment        | 防爆设备类型       |
| explosionproof_type             | 防爆类型           |
| danger                          | 危险区域等级       |
| gas_temperature                 | 气体类型和温度类型 |
| pollution_level                 | 污染等级           |
| contamination_level             | 污秽等级           |
| standard_energy_item            | 标准分项           |
| seismic_precautionary_intensity | 抗震设防烈度       |
| virtual_object                  | 虚拟对象类型       |
| calendar_tag                    | 日历标签           |
| calendar_interval               | 日历时间段         |
| consumable_all                  | 耗材编码           |
| tool_all                        | 工具编码           |

### 2.知识库数据

## 数据说明

1. 知识库中的数据，原则上只做增加
2. 知识库类型表保存知识库数据对应的大类
3. 知识库数据表保存实际的知识库类型对应的知识数据

## 数据结构

| 知识库/码表类型（dt_code_type） |                    |               |                                         |
| :-----------------------------: | :----------------: | :-----------: | :-------------------------------------: |
|              字段               |      字段说明      |   数据类型    |                  备注                   |
|               id                | 主键（无业务含义） |  varchar(20)  | id全局唯一，命名规则：“CODETYPE”+顺序码 |
|           group_code            |      集团编码      |  varchar(40)  |                                         |
|           project_id            |       项目id       |  varchar(40)  |      id规则:Pj+6位地区码+4位顺序码      |
|              code               |     知识库编码     |  varchar(40)  |                                         |
|              name               |   知识库类型名称   |  varchar(40)  |                                         |
|             extras              |      扩展属性      |  varchar(60)  |                                         |
|            tree_flag            |       树标识       |  tinyint(4)   |          0-列表结构,1-树型结构          |
|           show_order            |      显示顺序      |    int(11)    |                                         |
|             remark              |        备注        | varchar(1024) |                                         |
|             creator             |       创建人       |  varchar(32)  |                                         |
|          creation_time          |      创建时间      |   char(14)    |          格式为yyyyMMddHHmmss           |
|            modifier             |     最后修改人     |  varchar(32)  |                                         |
|          modified_time          |    最后修改时间    |   char(14)    |          格式为yyyyMMddHHmmss           |
|              valid              |      合法标识      |  tinyint(4)   |              1-有效,0-无效              |
|               ts                |       乐观锁       |   timestamp   |                                         |

| 知识库数据（dt_code_data） |                    |               |                               |
| :------------------------: | :----------------: | :-----------: | :---------------------------: |
|            字段            |      字段说明      |   数据类型    |             备注              |
|             id             | 主键（无业务含义） |  varchar(20)  | "CODEDATA"+18位0占位符+内部码 |
|         group_code         |      集团编码      |  varchar(40)  |                               |
|         project_id         |       项目id       |  varchar(40)  | id规则:Pj+6位地区码+4位顺序码 |
|          type_id           |       类型ID       |  varchar(40)  |                               |
|         type_code          |      类型编码      |  varchar(40)  |                               |
|            code            |        编码        |  varchar(40)  |                               |
|            name            |        名称        | varchar(200)  |                               |
|         parent_id          |       上级ID       |  varchar(40)  |         顶级上级id为0         |
|         inner_code         |       内部码       | varchar(255)  |                               |
|           extras           |      扩展属性      | varchar(2048) |                               |
|         show_order         |      显示顺序      |    int(11)    |                               |
|           remark           |        备注        | varchar(1024) |                               |
|          creator           |       创建人       |  varchar(32)  |                               |
|       creation_time        |      创建时间      |   char(14)    |     格式为yyyyMMddHHmmss      |
|          modifier          |     最后修改人     |  varchar(32)  |                               |
|       modified_time        |    最后修改时间    |   char(14)    |     格式为yyyyMMddHHmmss      |
|           valid            |      合法标识      |  tinyint(4)   |         0-无效,1-有效         |
|             ts             |       乐观锁       |   timestamp   |                               |



## 接口

### 10001-根据知识库类型查询知识库数据

http://localhost:8831/dmp-dic/dic/code/queryAll/{typeCode}

#### 请求方式

GET请求

#### RequestHeader

| key          | value            |
| ------------ | ---------------- |
| Content-Type | application/json |

#### 参数例子

```
typeCode:为知识库类型code,请参考数据模型下的知识库类型
```

#### 成功例子

```
{
    "result": "success",
    "data": [
        {
            "id": "CODEDATA000000000000000003000001",
            "valid": null,
            "creationTime": null,
            "creator": null,
            "modifiedTime": null,
            "modifier": null,
            "projectId": null,
            "typeId": null,
            "typeCode": null,
            "code": "1",
            "name": "晴",
            "parentId": null,
            "innerCode": null,
            "extras": null,
            "showOrder": null,
            "remark": null,
            "content": null
        }
    ],
    "count": 26
}
```

|     字段     | 是否必有 |      字段说明      |             备注              |
| :----------: | :------: | :----------------: | :---------------------------: |
|      id      |    是    | 主键（无业务含义） | "CODEDATA"+18位0占位符+内部码 |
|  groupCode   |    否    |      集团编码      |                               |
|  projectId   |    否    |       项目id       | id规则:Pj+6位地区码+4位顺序码 |
|    typeId    |    是    |       类型ID       |                               |
|   typeCode   |    是    |      类型编码      |                               |
|     code     |    是    |        编码        |                               |
|     name     |    是    |        名称        |                               |
|   parentId   |    否    |       上级ID       |         顶级上级id为0         |
|  innerCode   |    否    |       内部码       |                               |
|    extras    |    否    |      扩展属性      |          格式为{...}          |
|  showOrder   |    否    |      显示顺序      |                               |
|    remark    |    否    |        备注        |                               |
|   creator    |    否    |       创建人       |                               |
| creationTime |    否    |      创建时间      |     格式为yyyyMMddHHmmss      |
|   modifier   |    否    |     最后修改人     |                               |
| modifiedTime |    否    |    最后修改时间    |     格式为yyyyMMddHHmmss      |
|    valid     |    否    |      合法标识      |         0-无效,1-有效         |

#### 接口修改记录

| 操作时间              | 操作 | 操作内容 |
| --------------------- | ---- | -------- |
| 2021年8月12日14:25:15 | 新增 | 新增接口 |







